@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -32,6 +32,7 @@
 
 #include <glib-object.h>
 #include <glib/gi18n-lib.h>
+#include <gconf/gconf-client.h>
 
 #include <libepc/consumer.h>
 #include <libepc/enums.h>
@@ -39,6 +40,7 @@
 #include <libepc/service-monitor.h>
 
 #include <libepc-ui/progress-window.h>
+#include <gio/gio.h>
 
 #include "ev-sidebar.h"
 #include "totem-plugin.h"
@@ -69,6 +71,7 @@ typedef struct
 	TotemPlugin parent;
 
 	TotemObject       *totem;
+	GConfClient       *client;
 	GtkWidget         *settings;
 	GtkWidget         *scanning;
 	GtkBuilder        *ui;
@@ -131,7 +134,7 @@ totem_publish_plugin_service_name_entry_changed_cb (GtkEntry *entry,
 {
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (data);
 
-	gconf_client_set_string (self->totem->gc,
+	gconf_client_set_string (self->client,
 				 TOTEM_PUBLISH_CONFIG_NAME,
 				 gtk_entry_get_text (entry),
 				 NULL);
@@ -144,7 +147,7 @@ totem_publish_plugin_encryption_button_toggled_cb (GtkToggleButton *button,
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (data);
 	gboolean encryption = gtk_toggle_button_get_active (button);
 
-	gconf_client_set_string (self->totem->gc,
+	gconf_client_set_string (self->client,
 				 TOTEM_PUBLISH_CONFIG_PROTOCOL,
 				 encryption ? "https" : "http",
 				 NULL);
@@ -227,19 +230,20 @@ totem_publish_plugin_stream_cb (EpcContents *contents,
 				gsize       *length,
 				gpointer     data)
 {
-	GnomeVFSHandle *handle = data;
-	GnomeVFSFileSize size = 65536;
+	GInputStream *stream = data;
+	gssize size = 65536;
 
 	g_return_val_if_fail (NULL != contents, FALSE);
 	g_return_val_if_fail (NULL != length, FALSE);
 
-	if (NULL == data || *length < size) {
-		*length = MAX (*length, size);
+	if (NULL == data || *length < (gsize)size) {
+		*length = MAX (*length, (gsize)size);
 		return FALSE;
 	}
 
-	if (GNOME_VFS_OK != gnome_vfs_read (handle, buffer, size, &size)) {
-		gnome_vfs_close (handle);
+	size = g_input_stream_read (stream, buffer, size, NULL, NULL);
+	if (size == -1) {
+		g_input_stream_close (stream, NULL, NULL);
 		size = 0;
 	}
 
@@ -253,11 +257,21 @@ totem_publish_plugin_media_cb (EpcPublisher *publisher,
 			       const gchar  *key,
 			       gpointer      data)
 {
-	GnomeVFSHandle *handle = NULL;
+	GFileInputStream *stream;
 	const gchar *url = data;
+	GFile *file;
 
-	if (GNOME_VFS_OK == gnome_vfs_open (&handle, url, GNOME_VFS_OPEN_READ))
-		return epc_contents_stream_new (NULL, totem_publish_plugin_stream_cb, handle, NULL);
+	file = g_file_new_for_uri (url);
+	stream = g_file_read (file, NULL, NULL);
+	g_object_unref (file);
+
+	if (stream) {
+		EpcContents *output = epc_contents_stream_new (
+			NULL, totem_publish_plugin_stream_cb,
+			stream, g_object_unref);
+
+		return output;
+	}
 
 	return NULL;
 }
@@ -308,6 +322,7 @@ totem_publish_plugin_playlist_item_added_cb (TotemPlaylist *playlist,
 				   g_strdup (url), g_free);
 
 	g_free (key);
+
 }
 
 static void
@@ -404,6 +419,7 @@ totem_publish_plugin_load_playlist (TotemPublishPlugin   *self,
 		if (error)
 			goto out;
 
+		ev_sidebar_set_current_page (EV_SIDEBAR (self->totem->sidebar), "playlist");
 		totem_playlist_clear (self->totem->playlist);
 
 		for (i = 1; i <= n_entries; ++i) {
@@ -423,8 +439,6 @@ totem_publish_plugin_load_playlist (TotemPublishPlugin   *self,
 			g_free (title);
 			g_free (mrl);
 		}
-
-		ev_sidebar_set_current_page (EV_SIDEBAR (self->totem->sidebar), "playlist");
 	}
 
 out:
@@ -508,6 +522,7 @@ totem_publish_plugin_activate (TotemPlugin  *plugin,
 {
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (plugin);
 	EpcProtocol protocol = EPC_PROTOCOL_HTTPS;
+	GtkWindow *window;
 	GError *internal_error = NULL;
 
 	gchar *protocol_name;
@@ -522,35 +537,38 @@ totem_publish_plugin_activate (TotemPlugin  *plugin,
 
 	self->totem = g_object_ref (totem);
 	self->ui = totem_plugin_load_interface (plugin, "publish-plugin.ui", TRUE, NULL, self);
-	epc_progress_window_install (GTK_WINDOW (self->totem->win));
 
-	gconf_client_add_dir (self->totem->gc,
+	window = totem_get_main_window (self->totem);
+	epc_progress_window_install (window);
+	g_object_unref (window);
+
+	gconf_client_add_dir (self->client,
 			      TOTEM_PUBLISH_CONFIG_ROOT,
 			      GCONF_CLIENT_PRELOAD_ONELEVEL,
 			      NULL);
 
-	protocol_name = gconf_client_get_string (self->totem->gc, TOTEM_PUBLISH_CONFIG_PROTOCOL, NULL);
-	service_pattern = gconf_client_get_string (self->totem->gc, TOTEM_PUBLISH_CONFIG_NAME, NULL);
+	protocol_name = gconf_client_get_string (self->client, TOTEM_PUBLISH_CONFIG_PROTOCOL, NULL);
+	service_pattern = gconf_client_get_string (self->client, TOTEM_PUBLISH_CONFIG_NAME, NULL);
 
 	if (!protocol_name) {
 		protocol_name = g_strdup ("http");
-		gconf_client_set_string (self->totem->gc,
+		gconf_client_set_string (self->client,
 					 TOTEM_PUBLISH_CONFIG_PROTOCOL,
 					 protocol_name, NULL);
 	}
 
 	if (!service_pattern) {
 		service_pattern = g_strdup ("%a of %u on %h");
-		gconf_client_set_string (self->totem->gc,
+		gconf_client_set_string (self->client,
 					 TOTEM_PUBLISH_CONFIG_NAME,
 					 service_pattern, NULL);
 	}
 
-	self->name_id = gconf_client_notify_add (self->totem->gc,
+	self->name_id = gconf_client_notify_add (self->client,
 						 TOTEM_PUBLISH_CONFIG_NAME,
 						 totem_publish_plugin_name_changed_cb,
 						 self, NULL, NULL);
-	self->protocol_id = gconf_client_notify_add (self->totem->gc,
+	self->protocol_id = gconf_client_notify_add (self->client,
 						     TOTEM_PUBLISH_CONFIG_PROTOCOL,
 						     totem_publish_plugin_protocol_changed_cb,
 						     self, NULL, NULL);
@@ -567,7 +585,7 @@ totem_publish_plugin_activate (TotemPlugin  *plugin,
 	self->monitor = epc_service_monitor_new ("totem", NULL, EPC_PROTOCOL_UNKNOWN);
 	epc_service_monitor_set_skip_our_own (self->monitor, TRUE);
 
-	ev_sidebar_add_page (EV_SIDEBAR (self->totem->sidebar), "neighbours", _("Neighbours"),
+	ev_sidebar_add_page (EV_SIDEBAR (self->totem->sidebar), "neighbours", _("Neighbors"),
 			     totem_publish_plugin_create_neigbours_page (self));
 
 	self->publisher = epc_publisher_new (service_name, "totem", NULL);
@@ -588,12 +606,13 @@ totem_publish_plugin_activate (TotemPlugin  *plugin,
 	self->item_removed_id = g_signal_connect (self->totem->playlist, "item-removed",
 		G_CALLBACK (totem_publish_plugin_playlist_item_removed_cb), self);
 
-	totem_playlist_foreach (self->totem->playlist,
-				totem_publish_plugin_playlist_item_added_cb,
-				self);
-
 	G_UNLOCK (totem_publish_plugin_lock);
 
+	totem_playlist_foreach (self->totem->playlist,
+				totem_publish_plugin_playlist_item_added_cb, self);
+
+	totem_publish_plugin_playlist_changed_cb (self->totem->playlist, self);
+
 	return epc_publisher_run_async (self->publisher, error);
 }
 
@@ -636,9 +655,9 @@ totem_publish_plugin_deactivate (TotemPlugin *plugin,
 	}
 
 	if (self->totem) {
-		gconf_client_notify_remove (self->totem->gc, self->name_id);
-		gconf_client_notify_remove (self->totem->gc, self->protocol_id);
-		gconf_client_remove_dir (self->totem->gc, TOTEM_PUBLISH_CONFIG_ROOT, NULL);
+		gconf_client_notify_remove (self->client, self->name_id);
+		gconf_client_notify_remove (self->client, self->protocol_id);
+		gconf_client_remove_dir (self->client, TOTEM_PUBLISH_CONFIG_ROOT, NULL);
 
 		ev_sidebar_remove_page (EV_SIDEBAR (self->totem->sidebar), "neighbours");
 
@@ -682,7 +701,7 @@ totem_publish_plugin_create_configure_dialog (TotemPlugin *plugin)
 	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (plugin);
 
 	if (NULL == self->settings && GTK_IS_BUILDER (self->ui)) {
-		gchar *service_name = gconf_client_get_string (self->totem->gc, TOTEM_PUBLISH_CONFIG_NAME, NULL);
+		gchar *service_name = gconf_client_get_string (self->client, TOTEM_PUBLISH_CONFIG_NAME, NULL);
 		EpcProtocol protocol = epc_publisher_get_protocol (self->publisher);
 		GtkWidget *widget;
 
@@ -704,11 +723,18 @@ totem_publish_plugin_create_configure_dialog (TotemPlugin *plugin)
 static void
 totem_publish_plugin_init (TotemPublishPlugin *self)
 {
+	self->client = gconf_client_get_default ();
 }
 
 static void
 totem_publish_plugin_dispose (GObject *object)
 {
+	TotemPublishPlugin *self = TOTEM_PUBLISH_PLUGIN (object);
+
+	if (self->client != NULL) {
+		g_object_unref (self->client);
+		self->client = NULL;
+	}
 	totem_publish_plugin_deactivate (TOTEM_PLUGIN (object), NULL);
 	G_OBJECT_CLASS (totem_publish_plugin_parent_class)->dispose (object);
 }
