@@ -36,44 +36,46 @@
 
 #include "debug.h"
 
+#define TOTEM_MAX_RECENT_ITEM_LEN 40
+
 /* Callback functions for GtkBuilder */
-void open_action_callback (GtkAction *action, Totem *totem);
-void open_location_action_callback (GtkAction *action, Totem *totem);
-void eject_action_callback (GtkAction *action, Totem *totem);
-void properties_action_callback (GtkAction *action, Totem *totem);
-void play_action_callback (GtkAction *action, Totem *totem);
-void quit_action_callback (GtkAction *action, Totem *totem);
-void preferences_action_callback (GtkAction *action, Totem *totem);
-void fullscreen_action_callback (GtkAction *action, Totem *totem);
-void zoom_1_2_action_callback (GtkAction *action, Totem *totem);
-void zoom_1_1_action_callback (GtkAction *action, Totem *totem);
-void zoom_2_1_action_callback (GtkAction *action, Totem *totem);
-void zoom_in_action_callback (GtkAction *action, Totem *totem);
-void zoom_reset_action_callback (GtkAction *action, Totem *totem);
-void zoom_out_action_callback (GtkAction *action, Totem *totem);
-void next_angle_action_callback (GtkAction *action, Totem *totem);
-void dvd_root_menu_action_callback (GtkAction *action, Totem *totem);
-void dvd_title_menu_action_callback (GtkAction *action, Totem *totem);
-void dvd_audio_menu_action_callback (GtkAction *action, Totem *totem);
-void dvd_angle_menu_action_callback (GtkAction *action, Totem *totem);
-void dvd_chapter_menu_action_callback (GtkAction *action, Totem *totem);
-void next_chapter_action_callback (GtkAction *action, Totem *totem);
-void previous_chapter_action_callback (GtkAction *action, Totem *totem);
-void skip_forward_action_callback (GtkAction *action, Totem *totem);
-void skip_backwards_action_callback (GtkAction *action, Totem *totem);
-void volume_up_action_callback (GtkAction *action, Totem *totem);
-void volume_down_action_callback (GtkAction *action, Totem *totem);
-void contents_action_callback (GtkAction *action, Totem *totem);
-void about_action_callback (GtkAction *action, Totem *totem);
-void plugins_action_callback (GtkAction *action, Totem *totem);
-void repeat_mode_action_callback (GtkToggleAction *action, Totem *totem);
-void shuffle_mode_action_callback (GtkToggleAction *action, Totem *totem);
-void deinterlace_action_callback (GtkToggleAction *action, Totem *totem);
-void show_controls_action_callback (GtkToggleAction *action, Totem *totem);
-void show_sidebar_action_callback (GtkToggleAction *action, Totem *totem);
-void aspect_ratio_changed_callback (GtkRadioAction *action, GtkRadioAction *current, Totem *totem);
-void select_subtitle_action_callback (GtkAction *action, Totem *totem);
-void clear_playlist_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void open_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void open_location_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void eject_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void properties_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void play_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void quit_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void preferences_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void fullscreen_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void zoom_1_2_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void zoom_1_1_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void zoom_2_1_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void zoom_in_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void zoom_reset_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void zoom_out_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void next_angle_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void dvd_root_menu_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void dvd_title_menu_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void dvd_audio_menu_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void dvd_angle_menu_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void dvd_chapter_menu_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void next_chapter_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void previous_chapter_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void skip_forward_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void skip_backwards_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void volume_up_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void volume_down_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void contents_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void about_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void plugins_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void repeat_mode_action_callback (GtkToggleAction *action, Totem *totem);
+G_MODULE_EXPORT void shuffle_mode_action_callback (GtkToggleAction *action, Totem *totem);
+G_MODULE_EXPORT void deinterlace_action_callback (GtkToggleAction *action, Totem *totem);
+G_MODULE_EXPORT void show_controls_action_callback (GtkToggleAction *action, Totem *totem);
+G_MODULE_EXPORT void show_sidebar_action_callback (GtkToggleAction *action, Totem *totem);
+G_MODULE_EXPORT void aspect_ratio_changed_callback (GtkRadioAction *action, GtkRadioAction *current, Totem *totem);
+G_MODULE_EXPORT void select_subtitle_action_callback (GtkAction *action, Totem *totem);
+G_MODULE_EXPORT void clear_playlist_action_callback (GtkAction *action, Totem *totem);
 
 /* Helper function to escape underscores in labels
  * before putting them in menu items */
@@ -1160,14 +1162,11 @@ about_action_callback (GtkAction *action, Totem *totem)
 		"Ronald Bultje <rbultje@ronald.bitfreak.net>",
 		"Julien Moutte <julien@moutte.net> (GStreamer backend)",
 		"Tim-Philipp M\303\274ller <tim\100centricular\056net> (GStreamer backend)",
+		"Philip Withnall <philip@tecnocode.co.uk>",
 		NULL
 	};
 	const char *artists[] = { "Jakub Steiner <jimmac@ximian.com>", NULL };
-	const char *documenters[] =
-	{
-		"Chee Bin Hoh <cbhoh@gnome.org>",
-		NULL
-	};
+	#include "../help/totem-docs.h"
 	char *license = totem_interface_get_license ();
 
 	backend_version = bacon_video_widget_get_backend_name (totem->bvw);
@@ -1177,17 +1176,17 @@ about_action_callback (GtkAction *action, Totem *totem)
 
 	gtk_show_about_dialog (GTK_WINDOW (totem->win),
 				     "version", VERSION,
-				     "copyright", _("Copyright \xc2\xa9 2002-2008 Bastien Nocera"),
+				     "copyright", _("Copyright \xc2\xa9 2002-2009 Bastien Nocera"),
 				     "comments", description,
 				     "authors", authors,
-				     "documenters", documenters,
+				     "documenters", documentation_credits,
 				     "artists", artists,
 				     "translator-credits", _("translator-credits"),
 				     "logo-icon-name", "totem",
 				     "license", license,
 				     "wrap-license", TRUE,
 				     "website-label", _("Totem Website"),
-				     "website", "http://www.gnome.org/projects/totem/",
+				     "website", "http://projects.gnome.org/totem/",
 				     NULL);
 
 	g_free (backend_version);
