@@ -31,9 +31,9 @@
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
+#include <unique/uniqueapp.h>
 
 #include "totem-playlist.h"
-#include "bacon-message-connection.h"
 #include "bacon-video-widget.h"
 #include "totem-open-location.h"
 #include "totem-fullscreen.h"
@@ -157,7 +157,7 @@ struct TotemObject {
 	char *mrl;
 	TotemPlaylist *playlist;
 	GConfClient *gc;
-	BaconMessageConnection *conn;
+	UniqueApp *app;
 	TotemStates state;
 	TotemOpenLocation *open_location;
 };
@@ -170,13 +170,13 @@ GtkWidget *totem_volume_create (void);
 #define VOLUME_DOWN_OFFSET (-0.08)
 #define VOLUME_UP_OFFSET (0.08)
 
-#define ZOOM_IN_OFFSET 1
-#define ZOOM_OUT_OFFSET -1
+#define ZOOM_IN_OFFSET 0.01
+#define ZOOM_OUT_OFFSET -0.01
 
 void	totem_action_open			(Totem *totem);
 void	totem_action_open_location		(Totem *totem);
 void	totem_action_eject			(Totem *totem);
-void	totem_action_zoom_relative		(Totem *totem, int off_pct);
+void	totem_action_zoom_relative		(Totem *totem, double off_pct);
 void	totem_action_zoom_reset			(Totem *totem);
 void	totem_action_show_help			(Totem *totem);
 void	totem_action_show_properties		(Totem *totem);
